@@ -23,6 +23,7 @@ from UM.Preferences import Preferences
 from UM.View.Renderer import Renderer #For typing.
 from UM.OutputDevice.OutputDeviceManager import OutputDeviceManager
 from UM.i18n import i18nCatalog
+from UM.Version import Version
 
 from typing import TYPE_CHECKING, List, Callable, Any, Optional
 if TYPE_CHECKING:
@@ -44,14 +45,17 @@ class Application:
     #   \param version \type{string} Version, formatted as major.minor.rev
     #   \param build_type Additional version info on the type of build this is, such as "master".
     #   \param is_debug_mode Whether to run in debug mode.
-    def __init__(self, name: str, version: str, build_type: str = "", is_debug_mode: bool = False, **kwargs) -> None:
+    def __init__(self, name: str, version: str, api_version: str, app_display_name: str = "", build_type: str = "", is_debug_mode: bool = False, **kwargs) -> None:
         if Application.__instance is not None:
             raise RuntimeError("Try to create singleton '%s' more than once" % self.__class__.__name__)
         Application.__instance = self
 
         super().__init__()  # Call super to make multiple inheritance work.
 
+        self._api_version = Version(api_version)  # type: Version
+
         self._app_name = name #type: str
+        self._app_display_name = app_display_name if app_display_name else name  # type: str
         self._version = version #type: str
         self._build_type = build_type #type: str
         self._is_debug_mode = is_debug_mode #type: bool
@@ -68,7 +72,7 @@ class Application:
         self.default_theme = self._app_name  #type: str # Default theme is the application name
         self._default_language = "en_US" #type: str
 
-        self.change_log_url = "https://github.com/Ultimaker/Uranium" #Where to find a more detailed description of the recent updates.
+        self.change_log_url = "https://github.com/Ultimaker/Uranium" # Where to find a more detailed description of the recent updates.
 
         self._preferences_filename = None #type: str
         self._preferences = None #type: Preferences
@@ -94,6 +98,9 @@ class Application:
 
         self._app_install_dir = self.getInstallPrefix() #type: str
 
+    def getAPIVersion(self) -> "Version":
+        return self._api_version
+
     # Adds the command line options that can be parsed by the command line parser.
     # Can be overridden to add additional command line options to the parser.
     def addCommandLineOptions(self) -> None:
@@ -293,6 +300,9 @@ class Application:
     def getApplicationName(self) -> str:
         return self._app_name
 
+    def getApplicationDisplayName(self) -> str:
+        return self._app_display_name
+
     ##  Get the preferences.
     #   \return preferences \type{Preferences}
     def getPreferences(self) -> Preferences:
