@@ -45,6 +45,8 @@ class Backend(PluginObject):
         self._backend_log = []
         self._backend_log_max_lines = None
 
+        self._backend_state = BackendState.NotStarted
+
         UM.Application.Application.getInstance().callLater(self._createSocket)
 
     processingProgress = Signal()
@@ -52,6 +54,11 @@ class Backend(PluginObject):
     backendConnected = Signal()
     backendQuit = Signal()
 
+    def setState(self, new_state):
+        if new_state != self._backend_state:
+            self._backend_state = new_state
+            self.backendStateChange.emit(self._backend_state)
+
     ##   \brief Start the backend / engine.
     #   Runs the engine, this is only called when the socket is fully opened & ready to accept connections
     def startEngine(self):
@@ -145,6 +152,8 @@ class Backend(PluginObject):
             Logger.log("e", "Couldn't start back-end: No permission to execute process.")
         except FileNotFoundError:
             Logger.logException("e", "Unable to find backend executable: %s", command_list[0])
+        except BlockingIOError:
+            Logger.log("e", "Couldn't start back-end: Resource is temporarily unavailable")
         return None
 
     def _storeOutputToLogThread(self, handle):
