@@ -43,7 +43,10 @@ class Logger:
     #   \param **kwargs \type{dict} List of placeholder replacements that will be passed to str.format().
     @classmethod
     def log(cls, log_type: str, message: str, *args, **kwargs):
-        caller_frame = inspect.currentframe().f_back
+        current_frame = inspect.currentframe()
+        if current_frame is None:   # Avoid crash if the inspect module returns None (it should never happen)
+            return
+        caller_frame = current_frame.f_back
         frame_info = inspect.getframeinfo(caller_frame)
         try:
             if args or kwargs: # Only format the message if there are args
@@ -55,8 +58,7 @@ class Logger:
                 message = new_message
 
             current_thread = threading.current_thread()
-            thread_info = "(%s)-%s" % (current_thread.ident, current_thread.name)
-            message = "[{thread}] {class_name}.{function} [{line}]: {message}".format(thread = thread_info,
+            message = "[{thread}] {class_name}.{function} [{line}]: {message}".format(thread = current_thread.name,
                                                                                       class_name = caller_frame.f_globals["__name__"],
                                                                                       function = frame_info.function,
                                                                                       line = frame_info.lineno,
