@@ -82,27 +82,78 @@ class PackageManager(QObject):
                 self._bundled_package_dict.update(json.load(f, encoding = "utf-8"))
                 Logger.log("i", "Loaded bundled packages data from %s", search_path)
 
-        # Load the user package management file
-        if not os.path.exists(self._user_package_management_file_path):
-            Logger.log("i", "User package management file %s doesn't exist, do nothing", self._user_package_management_file_path)
-            return
-
         # Need to use the file lock here to prevent concurrent I/O from other processes/threads
         container_registry = self._application.getContainerRegistry()
         with container_registry.lockFile():
+            try:
+                # Load the user packages:
+                with open(self._user_package_management_file_path, "r", encoding="utf-8") as f:
+                    try:
+                        management_dict = json.load(f, encoding="utf-8")
+                    except JSONDecodeError:
+                        # The file got corrupted, ignore it. This happens extremely infrequently.
+                        # The file will get overridden once a user downloads something.
+                        return
+                    self._installed_package_dict = management_dict.get("installed", {})
+                    self._to_remove_package_set = set(management_dict.get("to_remove", []))
+                    self._to_install_package_dict = management_dict.get("to_install", {})
+                    Logger.log("i", "Loaded user packages management file from %s", self._user_package_management_file_path)
+            except FileNotFoundError:
+                Logger.log("i", "User package management file %s doesn't exist, do nothing", self._user_package_management_file_path)
+                return
 
-            # Load the user packages:
-            with open(self._user_package_management_file_path, "r", encoding="utf-8") as f:
-                try:
-                    management_dict = json.load(f, encoding="utf-8")
-                except JSONDecodeError:
-                    # The file got corrupted, ignore it. This happens extremely infrequently.
-                    # The file will get overridden once a user downloads something.
-                    return
-                self._installed_package_dict = management_dict.get("installed", {})
-                self._to_remove_package_set = set(management_dict.get("to_remove", []))
-                self._to_install_package_dict = management_dict.get("to_install", {})
-                Logger.log("i", "Loaded user packages management file from %s", self._user_package_management_file_path)
+        # For packages that become bundled in the new releases, but a lower version was installed previously, we need
+        # to remove the old lower version that's installed in the user's folder.
+        for package_id, installed_package_dict in self._installed_package_dict.items():
+            bundled_package_dict = self._bundled_package_dict.get(package_id)
+            if bundled_package_dict is None:
+                continue
+
+            result = self._comparePackageVersions(installed_package_dict["package_info"],
+                                                  bundled_package_dict["package_info"])
+            # The bundled package is newer
+            if result <= 0:
+                self._to_remove_package_set.add(package_id)
+                continue
+
+        # Also check the to-install packages to avoid installing packages that have a lower version than the bundled
+        # ones.
+        to_remove_package_ids = set()
+        for package_id, to_install_package_dict in self._to_install_package_dict.items():
+            bundled_package_dict = self._bundled_package_dict.get(package_id)
+            if bundled_package_dict is None:
+                continue
+
+            result = self._comparePackageVersions(to_install_package_dict["package_info"],
+                                                  bundled_package_dict["package_info"])
+            # The bundled package is newer
+            if result <= 0:
+                to_remove_package_ids.add(package_id)
+                continue
+        for package_id in to_remove_package_ids:
+            del self._to_install_package_dict[package_id]
+
+    # Compares the SDK versions and the package versions of the two given package info dicts.
+    # Returns -1, 0, 1 indicating if the versions in dict1 is lower than, equal to, or higher than dict2.
+    #  - The package with the higher SDK version is considered having the higher version number. If they are the same,
+    #  - if the bundled package version is greater than or equal to the given package, -1 is returned. Otherwise, 1.
+    def _comparePackageVersions(self, info_dict1: Dict[str, Any], info_dict2: Dict[str, Any]) -> int:
+        # If the bundled version has a higher SDK version, use the bundled version by removing the installed one.
+        sdk_version1 = Version(info_dict1["sdk_version"])
+        sdk_version2 = Version(info_dict2["sdk_version"])
+        if sdk_version1 < sdk_version2:
+            return -1
+
+        # Remove the package with the old version to favour the newer bundled version.
+        version1 = Version(info_dict1["package_version"])
+        version2 = Version(info_dict2["package_version"])
+        if version1 < version2:
+            return -1
+
+        if version1 == version2:
+            return 0
+
+        return 1
 
     def _saveManagementData(self) -> None:
         # Need to use the file lock here to prevent concurrent I/O from other processes/threads
@@ -350,6 +401,7 @@ class PackageManager(QObject):
             dst_dir_path = os.path.join(installation_root_dir, package_id)
 
             if not os.path.exists(src_dir_path):
+                Logger.log("w", "The path %s does not exist, so not installing the files", src_dir_path)
                 continue
             self.__installPackageFiles(package_id, src_dir_path, dst_dir_path)
 
@@ -370,23 +422,26 @@ class PackageManager(QObject):
     # Gets package information from the given file.
     def getPackageInfo(self, filename: str) -> Dict[str, Any]:
         package_json = {}  # type: Dict[str, Any]
-        with zipfile.ZipFile(filename) as archive:
-            # Go through all the files and use the first successful read as the result
-            for file_info in archive.infolist():
-                if file_info.filename.endswith("package.json"):
-                    Logger.log("d", "Found potential package.json file '%s'", file_info.filename)
-                    try:
-                        with archive.open(file_info.filename, "r") as f:
-                            package_json = json.loads(f.read().decode("utf-8"))
+        try:
+            with zipfile.ZipFile(filename) as archive:
+                # Go through all the files and use the first successful read as the result
+                for file_info in archive.infolist():
+                    if file_info.filename.endswith("package.json"):
+                        Logger.log("d", "Found potential package.json file '%s'", file_info.filename)
+                        try:
+                            with archive.open(file_info.filename, "r") as f:
+                                package_json = json.loads(f.read().decode("utf-8"))
 
-                        # Add by default properties
-                        package_json["is_active"] = True
-                        package_json["is_bundled"] = False
-                        package_json["is_installed"] = False
-                        break
-                    except:
-                        Logger.logException("e", "Failed to load potential package.json file '%s' as text file.",
-                                            file_info.filename)
+                            # Add by default properties
+                            package_json["is_active"] = True
+                            package_json["is_bundled"] = False
+                            package_json["is_installed"] = False
+                            break
+                        except:
+                            Logger.logException("e", "Failed to load potential package.json file '%s' as text file.",
+                                                file_info.filename)
+        except zipfile.BadZipFile:
+            Logger.logException("e", "Failed to unpack the file %s", filename)
         return package_json
 
     # Gets the license file content if present in the given package file.
