@@ -7,12 +7,8 @@ import os
 import shutil  # For deleting plugin directories;
 import stat    # For setting file permissions correctly;
 import zipfile
-
-from UM.Preferences import Preferences
-from UM.PluginError import PluginNotFoundError, InvalidMetaDataError
-from UM.Logger import Logger
-from typing import Any, Callable, Dict, List, Optional, Tuple, TYPE_CHECKING
 import types
+from typing import Any, Callable, Dict, List, Optional, Tuple, TYPE_CHECKING
 
 from PyQt5.QtCore import QObject, pyqtSlot, QUrl, pyqtProperty, pyqtSignal
 
@@ -41,15 +37,14 @@ if TYPE_CHECKING:
 #   [plugins]: docs/plugins.md
 
 class PluginRegistry(QObject):
-    APIVersion = 5
-
     def __init__(self, application: "Application", parent: QObject = None) -> None:
         if PluginRegistry.__instance is not None:
             raise RuntimeError("Try to create singleton '%s' more than once" % self.__class__.__name__)
         PluginRegistry.__instance = self
 
         super().__init__(parent)
-        self._application = application #type: Application
+        self._application = application  # type: Application
+        self._api_version = application.getAPIVersion()  # type: Version
 
         self._all_plugins = []        # type: List[str]
         self._metadata = {}           # type: Dict[str, Dict[str, Any]]
@@ -61,6 +56,7 @@ class PluginRegistry(QObject):
         # When actually loading the preferences, it's set to a list. This way we can see the
         # difference between no list and an empty one.
         self._disabled_plugins = []  # type: List[str]
+        self._outdated_plugins = []  # type: List[str]
         self._plugins_to_install = dict()  # type: Dict[str, dict]
         self._plugins_to_remove = []  # type: List[str]
 
@@ -73,6 +69,8 @@ class PluginRegistry(QObject):
         self._plugin_locations = []  # type: List[str]
         self._folder_cache = {}      # type: Dict[str, List[Tuple[str, str]]]
 
+        self._bundled_plugin_cache = {}  # type: Dict[str, bool]
+
         self._supported_file_types = {"umplugin": "Uranium Plugin"} # type: Dict[str, str]
 
     def initializeBeforePluginsAreLoaded(self) -> None:
@@ -239,7 +237,7 @@ class PluginRegistry(QObject):
         active_only = kwargs.get("active_only", False)
         metadata_list = []
         for plugin_id in self._all_plugins:
-            if active_only and plugin_id in self._disabled_plugins:
+            if active_only and (plugin_id in self._disabled_plugins or plugin_id in self._outdated_plugins):
                 continue
             plugin_metadata = self.getMetaData(plugin_id)
             if self._subsetInDict(plugin_metadata, data_filter):
@@ -316,8 +314,9 @@ class PluginRegistry(QObject):
 
     #   Check by ID if a plugin is active (enabled):
     def isActivePlugin(self, plugin_id: str) -> bool:
-        if plugin_id not in self._disabled_plugins:
+        if plugin_id not in self._disabled_plugins and plugin_id not in self._outdated_plugins:
             return True
+
         return False
 
     #   Check by ID if a plugin is available:
@@ -329,6 +328,8 @@ class PluginRegistry(QObject):
         return plugin_id in self._plugins_installed
 
     def isBundledPlugin(self, plugin_id: str) -> bool:
+        if plugin_id in self._bundled_plugin_cache:
+            return self._bundled_plugin_cache[plugin_id]
         install_prefix = os.path.abspath(self._application.getInstallPrefix())
 
         # Go through all plugin locations and check if the given plugin is located in the installation path.
@@ -345,7 +346,7 @@ class PluginRegistry(QObject):
             if result:
                 is_bundled = True
                 break
-
+        self._bundled_plugin_cache[plugin_id] = is_bundled
         return is_bundled
 
     ##  Load all plugins matching a certain set of metadata
@@ -371,6 +372,11 @@ class PluginRegistry(QObject):
                 except PluginNotFoundError:
                     pass
 
+    # Checks if the given plugin API version is compatible with the current version.
+    def isPluginApiVersionCompatible(self, plugin_api_version: "Version") -> bool:
+        return plugin_api_version.getMajor() == self._api_version.getMajor() \
+               and plugin_api_version.getMinor() <= self._api_version.getMinor()
+
     #   Load a single plugin by ID:
     def loadPlugin(self, plugin_id: str) -> None:
         # If plugin has already been loaded, do not load it again:
@@ -378,11 +384,6 @@ class PluginRegistry(QObject):
             Logger.log("w", "Plugin %s was already loaded", plugin_id)
             return
 
-        # If the plugin is in the list of disabled plugins, alert and return:
-        if plugin_id in self._disabled_plugins:
-            Logger.log("d", "Plugin %s was disabled", plugin_id)
-            return
-
         # Find the actual plugin on drive:
         plugin = self._findPlugin(plugin_id)
 
@@ -397,14 +398,27 @@ class PluginRegistry(QObject):
             except InvalidMetaDataError:
                 return
 
-        #If API version is incompatible, don't load it.
-        if self._metadata[plugin_id].get("plugin", {}).get("api", 0) != self.APIVersion:
-            Logger.log("w", "Plugin %s uses an incompatible API version, ignoring", plugin_id)
-            del self._metadata[plugin_id]
+        # Do not load plugin that has been disabled
+        if plugin_id in self._disabled_plugins:
+            Logger.log("i", "Plugin [%s] has been disabled. Skip loading it.", plugin_id)
+            return
+
+        # If API version is incompatible, don't load it.
+        supported_sdk_versions = self._metadata[plugin_id].get("plugin", {}).get("supported_sdk_versions", [Version("0")])
+        is_plugin_supported = False
+        for supported_sdk_version in supported_sdk_versions:
+            is_plugin_supported |= self.isPluginApiVersionCompatible(supported_sdk_version)
+            if is_plugin_supported:
+                break
+
+        if not is_plugin_supported:
+            Logger.log("w", "Plugin [%s] with supported sdk versions [%s] is incompatible with the current sdk version [%s].",
+                       plugin_id, [str(version) for version in supported_sdk_versions], self._api_version)
+            self._outdated_plugins.append(plugin_id)
             return
 
         try:
-            to_register = plugin.register(self._application) #type: ignore #We catch AttributeError on this in case register() doesn't exist.
+            to_register = plugin.register(self._application)  # type: ignore  # We catch AttributeError on this in case register() doesn't exist.
             if not to_register:
                 Logger.log("e", "Plugin %s did not return any objects to register", plugin_id)
                 return
@@ -421,10 +435,7 @@ class PluginRegistry(QObject):
             self.enablePlugin(plugin_id)
             Logger.log("i", "Loaded plugin %s", plugin_id)
 
-        except KeyError as e:
-            Logger.log("e", "Error loading plugin %s:", plugin_id)
-            Logger.log("e", "Unknown plugin type: %s", str(e))
-        except Exception as e:
+        except Exception as ex:
             Logger.logException("e", "Error loading plugin %s:", plugin_id)
 
     #   Uninstall a plugin with a given ID:
@@ -458,6 +469,9 @@ class PluginRegistry(QObject):
 
         local_plugin_path = os.path.join(Resources.getStoragePath(Resources.Resources), "plugins")
 
+        if plugin_id in self._bundled_plugin_cache:
+            del self._bundled_plugin_cache[plugin_id]
+
         try:
             with zipfile.ZipFile(plugin_path, "r") as zip_ref:
                 plugin_folder = os.path.join(local_plugin_path, plugin_id)
@@ -483,6 +497,9 @@ class PluginRegistry(QObject):
         plugin_folder = os.path.join(Resources.getStoragePath(Resources.Resources), "plugins")
         plugin_path = os.path.join(plugin_folder, plugin_id)
 
+        if plugin_id in self._bundled_plugin_cache:
+            del self.bundled_plugin_cache[plugin_id]
+
         Logger.log("i", "Attempting to remove plugin '%s' from directory '%s'", plugin_id, plugin_path)
         shutil.rmtree(plugin_path)
 
@@ -567,7 +584,7 @@ class PluginRegistry(QObject):
                     sub_folders.append(entry)
             self._folder_cache[folder] = sub_folders
 
-        for (file, file_path) in self._folder_cache[folder]:
+        for file, file_path in self._folder_cache[folder]:
             if file == plugin_id and os.path.exists(os.path.join(file_path, "__init__.py")):
                 return folder
             else:
@@ -615,6 +632,19 @@ class PluginRegistry(QObject):
                         Logger.log("e", "Version must be set!")
                         raise InvalidMetaDataError(plugin_id)
 
+                    # Check if the plugin states what API version it needs.
+                    if "api" not in meta_data["plugin"] and "supported_sdk_versions" not in meta_data["plugin"]:
+                        Logger.log("e", "The API or the supported_sdk_versions must be set!")
+                        raise InvalidMetaDataError(plugin_id)
+                    else:
+                        # Store the api_version as a Version object.
+                        all_supported_sdk_versions = []  # type: List[Version]
+                        if "supported_sdk_versions" in meta_data["plugin"]:
+                            all_supported_sdk_versions += [Version(supported_version) for supported_version in meta_data["plugin"]["supported_sdk_versions"]]
+                        if "api" in meta_data["plugin"]:
+                            all_supported_sdk_versions += [Version(meta_data["plugin"]["api"])]
+                        meta_data["plugin"]["supported_sdk_versions"] = all_supported_sdk_versions
+
                     if "i18n-catalog" in meta_data["plugin"]:
                         # A catalog was set, try to translate a few strings
                         i18n_catalog = i18nCatalog(meta_data["plugin"]["i18n-catalog"])
