@@ -16,19 +16,36 @@ class ControllerProxy(QObject):
         self._selection_pass = None
         self._tools_enabled = True
 
+        # bind needed signals
         self._controller.toolOperationStarted.connect(self._onToolOperationStarted)
         self._controller.toolOperationStopped.connect(self._onToolOperationStopped)
+        self._controller.activeStageChanged.connect(self._onActiveStageChanged)
+        self._controller.activeViewChanged.connect(self._onActiveViewChanged)
 
     toolsEnabledChanged = pyqtSignal()
+    activeStageChanged = pyqtSignal()
+    activeViewChanged = pyqtSignal()
 
     @pyqtProperty(bool, notify = toolsEnabledChanged)
     def toolsEnabled(self):
         return self._tools_enabled
 
+    @pyqtProperty(QObject, notify = activeStageChanged)
+    def activeStage(self):
+        return self._controller.getActiveStage()
+
     @pyqtSlot(str)
     def setActiveView(self, view):
         self._controller.setActiveView(view)
 
+    @pyqtProperty(QObject, notify = activeViewChanged)
+    def activeView(self):
+        return self._controller.getActiveView()
+
+    @pyqtSlot(str)
+    def setActiveStage(self, stage):
+        self._controller.setActiveStage(stage)
+
     @pyqtSlot(str)
     def setActiveTool(self, tool):
         self._controller.setActiveTool(tool)
@@ -44,6 +61,22 @@ class ControllerProxy(QObject):
         op.push()
         Selection.clear()
 
+    @pyqtSlot()
+    def enableModelRendering(self):
+        self._controller.enableModelRendering()
+
+    @pyqtSlot()
+    def disableModelRendering(self):
+        self._controller.disableModelRendering()
+
+    @pyqtSlot(str, int)
+    def rotateView(self,coordinate, angle):
+        self._controller.rotateView(coordinate, angle)
+
+    @pyqtSlot()
+    def homeView(self, angle):
+        self._controller.homeView()
+
     contextMenuRequested = pyqtSignal("quint64", arguments=["objectId"])
 
     def _onContextMenuRequested(self, x, y):
@@ -65,4 +98,10 @@ class ControllerProxy(QObject):
     def _onToolOperationStopped(self, tool):
         self._tools_enabled = True
         self._controller.setToolsEnabled(True)
-        self.toolsEnabledChanged.emit()
\ No newline at end of file
+        self.toolsEnabledChanged.emit()
+
+    def _onActiveStageChanged(self):
+        self.activeStageChanged.emit()
+
+    def _onActiveViewChanged(self):
+        self.activeViewChanged.emit()
