@@ -1,12 +1,13 @@
-# Copyright (c) 2015 Ultimaker B.V.
+# Copyright (c) 2018 Ultimaker B.V.
 # Uranium is released under the terms of the LGPLv3 or higher.
 
-from PyQt5.QtCore import QAbstractListModel, QCoreApplication, Qt, QVariant
+from PyQt5.QtCore import Qt
 
 from UM.Qt.ListModel import ListModel
 from UM.Application import Application
 from UM.PluginRegistry import PluginRegistry
 
+
 class ViewModel(ListModel):
     IdRole = Qt.UserRole + 1
     NameRole = Qt.UserRole + 2
@@ -14,12 +15,12 @@ class ViewModel(ListModel):
     DescriptionRole = Qt.UserRole + 4
     IconRole = Qt.UserRole + 5
 
-    def __init__(self, parent = None):
+    def __init__(self, parent = None) -> None:
         super().__init__(parent)
         self._controller = Application.getInstance().getController()
-        self._controller.viewsChanged.connect(self._onViewsChanged)
-        self._controller.activeViewChanged.connect(self._onViewsChanged)
-        self._onViewsChanged()  
+        self._controller.viewsChanged.connect(self._update)
+        self._controller.activeViewChanged.connect(self._update)
+        self._update()
 
         self.addRoleName(self.IdRole, "id")
         self.addRoleName(self.NameRole, "name")
@@ -27,34 +28,34 @@ class ViewModel(ListModel):
         self.addRoleName(self.DescriptionRole, "description")
         self.addRoleName(self.IconRole, "icon")
 
-    def _onViewsChanged(self):
+    def _update(self) -> None:
         items = []
         views = self._controller.getAllViews()
-        currentView = self._controller.getActiveView()
-        if currentView is None:
+        current_view = self._controller.getActiveView()
+        if current_view is None:
             return
 
-        for id in views:
-            viewMetaData = PluginRegistry.getInstance().getMetaData(id).get("view", {})
+        for view_id in views:
+            view_meta_data = PluginRegistry.getInstance().getMetaData(view_id).get("view", {})
 
             # Skip view modes that are marked as not visible
-            if "visible" in viewMetaData and not viewMetaData["visible"]:
+            if "visible" in view_meta_data and not view_meta_data["visible"]:
                 continue
 
             # Metadata elements
-            name = viewMetaData.get("name", id)
-            description = viewMetaData.get("description", "")
-            iconName = viewMetaData.get("icon", "")
-            weight = viewMetaData.get("weight", 0)
+            name = view_meta_data.get("name", view_id)
+            description = view_meta_data.get("description", "")
+            icon_name = view_meta_data.get("icon", "")
+            weight = view_meta_data.get("weight", 0)
 
             items.append({
-                "id": id,
+                "id": view_id,
                 "name": name,
-                "active": id == currentView.getPluginId(),
+                "active": view_id == current_view.getPluginId(),
                 "description": description,
-                "icon": iconName,
+                "icon": icon_name,
                 "weight": weight
             })
 
         items.sort(key = lambda t: t["weight"])
-        self.setItems(items)
\ No newline at end of file
+        self.setItems(items)
