@@ -1,23 +1,23 @@
 # Copyright (c) 2015 Ultimaker B.V.
-# Uranium is released under the terms of the AGPLv3 or higher.
+# Uranium is released under the terms of the LGPLv3 or higher.
 
 import inspect
 
-from PyQt5.QtCore import pyqtProperty, pyqtSignal, QObject, QUrl, QCoreApplication, pyqtSlot
+from PyQt5.QtCore import pyqtProperty, pyqtSignal, QObject, QCoreApplication, pyqtSlot
 from PyQt5.QtQml import QJSValue
-# from UM.FlameProfiler import pyqtSlot
 
 from UM.i18n import i18nCatalog
 
+
 class i18nCatalogProxy(QObject): # [CodeStyle: Ultimaker code style requires classes to start with a upper case. But i18n is lower case by convention.]
     def __init__(self, parent = None):
-        super().__init__()
+        super().__init__(parent)
 
         self._name = None
         self._catalog = None
 
         # Slightly hacky way of getting at the QML engine defined by QtApplication.
-        engine = QCoreApplication.instance()._engine
+        engine = QCoreApplication.instance()._qml_engine
 
         self._i18n_function = self._wrapFunction(engine, self, self._call_i18n)
         self._i18nc_function = self._wrapFunction(engine, self, self._call_i18nc)
@@ -86,9 +86,9 @@ class i18nCatalogProxy(QObject): # [CodeStyle: Ultimaker code style requires cla
     #   \todo Move this to a more generic place so more things can use it.
     def _wrapFunction(self, engine, this_object, function):
         # JavaScript code that wraps the Python method call in a closure
-        wrap_js = """function(this_object) {{
+        wrap_js = """(function(this_object) {{
             return function({args}) {{ return this_object.{function}({args}) }}
-        }}"""
+        }})"""
 
         # Get the function name and argument list.
         function_name = function.__name__
