@@ -56,10 +56,10 @@ class UnsupportedVersionError(Exception):
     pass
 
 
-# Check PyQt version, we only support 5.4 or higher.
+# Check PyQt version, we only support 5.9 or higher.
 major, minor = PYQT_VERSION_STR.split(".")[0:2]
-if int(major) < 5 or (int(major) == 5 and int(minor) < 4):
-    raise UnsupportedVersionError("This application requires at least PyQt 5.4.0")
+if int(major) < 5 or (int(major) == 5 and int(minor) < 9):
+    raise UnsupportedVersionError("This application requires at least PyQt 5.9.0")
 
 
 ##  Application subclass that provides a Qt application object.
@@ -417,6 +417,9 @@ class QtApplication(QApplication, Application):
         Logger.log("d", "Shutting down %s", self.getApplicationName())
         self._is_shutting_down = True
 
+        # garbage collect tray icon so it gets properly closed before the application is closed
+        self._tray_icon_widget = None
+
         if save_data:
             try:
                 self.savePreferences()
@@ -433,6 +436,9 @@ class QtApplication(QApplication, Application):
         except Exception as e:
             Logger.log("e", "Exception while closing backend: %s", repr(e))
 
+        if self._tray_icon_widget:
+            self._tray_icon_widget.deleteLater()
+
         self.quit()
 
     def checkWindowMinimizedState(self) -> bool:
