@@ -6,16 +6,16 @@ import io
 from typing import Any, cast, Dict, List, Optional, Set, Tuple
 
 from PyQt5.QtCore import QObject, pyqtProperty, pyqtSignal
+
+from UM.Logger import Logger
 from PyQt5.QtQml import QQmlEngine
 import UM.FlameProfiler
 
 from UM.ConfigurationErrorMessage import ConfigurationErrorMessage
 from UM.Signal import Signal, signalemitter
 from UM.PluginObject import PluginObject
-from UM.Logger import Logger
 from UM.MimeTypeDatabase import MimeTypeDatabase, MimeType
 from UM.Settings.ContainerFormatError import ContainerFormatError
-import UM.Settings.ContainerRegistry
 from UM.Settings.DefinitionContainer import DefinitionContainer #For getting all definitions in this stack.
 from UM.Settings.Interfaces import ContainerInterface, ContainerRegistryInterface
 from UM.Settings.PropertyEvaluationContext import PropertyEvaluationContext
@@ -31,6 +31,7 @@ class IncorrectVersionError(Exception):
 class InvalidContainerStackError(Exception):
     pass
 
+
 MimeTypeDatabase.addMimeType(
     MimeType(
         name = "application/x-uranium-containerstack",
@@ -137,9 +138,20 @@ class ContainerStack(QObject, ContainerInterface, PluginObject):
 
     ##  Set the complete set of metadata
     def setMetaData(self, meta_data: Dict[str, Any]) -> None:
-        if meta_data != self.getMetaData():
-            self._metadata = meta_data
-            self.metaDataChanged.emit(self)
+        if meta_data == self.getMetaData():
+            return #Unnecessary.
+
+        #We'll fill a temporary dictionary with all the required metadata and overwrite it with the new metadata.
+        #This way it is ensured that at least the required metadata is still there.
+        self._metadata = {
+            "id": self.getId(),
+            "name": self.getName(),
+            "version": self.getMetaData().get("version", 0),
+            "container_type": ContainerStack
+        }
+
+        self._metadata.update(meta_data)
+        self.metaDataChanged.emit(self)
 
     metaDataChanged = pyqtSignal(QObject)
     metaData = pyqtProperty("QVariantMap", fget = getMetaData, fset = setMetaData, notify = metaDataChanged)
@@ -161,21 +173,11 @@ class ContainerStack(QObject, ContainerInterface, PluginObject):
         else:
             return value
 
-    def addMetaDataEntry(self, key: str, value: Any) -> None:
-        if key not in self._metadata:
-            self._dirty = True
-            self._metadata[key] = value
-            self.metaDataChanged.emit(self)
-        else:
-            Logger.log("w", "Meta data with key %s was already added.", key)
-
     def setMetaDataEntry(self, key: str, value: Any) -> None:
-        if key in self._metadata:
-            self._dirty = True
+        if key not in self._metadata or self._metadata[key] != value:
             self._metadata[key] = value
+            self._dirty = True
             self.metaDataChanged.emit(self)
-        else:
-            Logger.log("w", "Meta data with key %s was not found. Unable to change.", key)
 
     def removeMetaDataEntry(self, key: str) -> None:
         if key in self._metadata:
@@ -313,7 +315,7 @@ class ContainerStack(QObject, ContainerInterface, PluginObject):
     #   the serialized data. Due to legacy problem, those data may not be available if it comes from an ancient Cura.
     @classmethod
     def _readAndValidateSerialized(cls, serialized: str) -> configparser.ConfigParser:
-        parser = configparser.ConfigParser(interpolation=None, empty_lines_in_values=False)
+        parser = configparser.ConfigParser(interpolation = None, empty_lines_in_values=False)
         parser.read_string(serialized)
 
         if "general" not in parser or any(pn not in parser["general"] for pn in ("version", "name", "id")):
@@ -340,12 +342,11 @@ class ContainerStack(QObject, ContainerInterface, PluginObject):
             Logger.log("d", "Could not get type from serialized.")
             return None
 
-        # get version
+        # Get version
         version = None
         try:
-            import UM.VersionUpgradeManager
-            version = UM.VersionUpgradeManager.VersionUpgradeManager.getInstance().getFileVersion(configuration_type,
-                                                                                                  serialized)
+            from UM.VersionUpgradeManager import VersionUpgradeManager
+            version = VersionUpgradeManager.getInstance().getFileVersion(configuration_type, serialized)
         except Exception as e:
             Logger.log("d", "Could not get version from serialized: %s", e)
         return version
@@ -355,12 +356,12 @@ class ContainerStack(QObject, ContainerInterface, PluginObject):
     #   Reimplemented from ContainerInterface
     #
     #   TODO: Expand documentation here, include the fact that this should _not_ include all containers
-    def deserialize(self, serialized, file_name = None) -> str:
-        # update the serialized data first
+    def deserialize(self, serialized: str, file_name: Optional[str] = None) -> str:
+        # Update the serialized data first
         serialized = super().deserialize(serialized, file_name)
         parser = self._readAndValidateSerialized(serialized)
 
-        if parser["general"].getint("version") != self.Version:
+        if parser.getint("general", "version") != self.Version:
             raise IncorrectVersionError()
 
         # Clear all data before starting.
@@ -374,7 +375,7 @@ class ContainerStack(QObject, ContainerInterface, PluginObject):
             self._metadata = dict(parser["metadata"])
         self._metadata["id"] = parser["general"]["id"]
         self._metadata["name"] = parser["general"].get("name", self.getId())
-        self._metadata["version"] = self.Version #Guaranteed to be equal to what's in the container. See above.
+        self._metadata["version"] = self.Version  # Guaranteed to be equal to what's in the container. See above.
         self._metadata["container_type"] = ContainerStack
 
         if "containers" in parser:
@@ -423,7 +424,7 @@ class ContainerStack(QObject, ContainerInterface, PluginObject):
     #   instead.
     @classmethod
     def deserializeMetadata(cls, serialized: str, container_id: str) -> List[Dict[str, Any]]:
-        serialized = cls._updateSerialized(serialized) #Update to most recent version.
+        serialized = cls._updateSerialized(serialized)  # Update to most recent version.
         parser = configparser.ConfigParser(interpolation = None)
         parser.read_string(serialized)
 
@@ -434,7 +435,7 @@ class ContainerStack(QObject, ContainerInterface, PluginObject):
         try:
             metadata["name"] = parser["general"]["name"]
             metadata["version"] = parser["general"]["version"]
-        except KeyError as e: #One of the keys or the General section itself is missing.
+        except KeyError as e:  # One of the keys or the General section itself is missing.
             raise InvalidContainerStackError("Missing required fields: {error_msg}".format(error_msg = str(e)))
 
         if "metadata" in parser:
@@ -449,7 +450,7 @@ class ContainerStack(QObject, ContainerInterface, PluginObject):
     #
     #   \return A set of all setting keys in this container stack.
     def getAllKeys(self) -> Set[str]:
-        keys = set()    # type: Set[str]
+        keys = set()  # type: Set[str]
         definition_containers = [container for container in self.getContainers() if container.__class__ == DefinitionContainer] #To get all keys, get all definitions from all definition containers.
         for definition_container in cast(List[DefinitionContainer], definition_containers):
             keys |= definition_container.getAllKeys()
@@ -712,7 +713,8 @@ class ContainerStack(QObject, ContainerInterface, PluginObject):
         self._property_changes[key].add(property_name)
 
         if not self._emit_property_changed_queued:
-            _containerRegistry.getApplication().callLater(self._emitCollectedPropertyChanges)
+            from UM.Application import Application
+            Application.getInstance().callLater(self._emitCollectedPropertyChanges)
             self._emit_property_changed_queued = True
 
     # Perform the emission of the change signals that were collected in a previous step.
@@ -726,7 +728,12 @@ class ContainerStack(QObject, ContainerInterface, PluginObject):
         self._property_changes = {}
         self._emit_property_changed_queued = False
 
-_containerRegistry = ContainerRegistryInterface() # type: ContainerRegistryInterface
+    def __str__(self) -> str:
+        return "%s(%s)" % (type(self).__name__, self.getId())
+
+
+_containerRegistry = ContainerRegistryInterface()  # type: ContainerRegistryInterface
+
 
 def setContainerRegistry(registry: ContainerRegistryInterface) -> None:
     global _containerRegistry
