@@ -430,17 +430,33 @@ class SettingDefinitionsModel(QAbstractListModel):
 
         return result
 
+    ##  Reimplemented from ListModel only because we want to use it in static
+    #   context in the subclass.
+    itemsChanged = pyqtSignal()
+
     ##  Reimplemented from QAbstractListModel
-    # Note that rowCount() is overridden from QAbstractItemModel. The signature of the method in that
-    # class is "int rowCount(const QModelIndex& parent)" which makes this slot declaration incorrect.
-    # TODO: fix the pointer when actually using this parameter.
-    @pyqtSlot(QObject, result = int)
-    def rowCount(self, parent = None):
+    #
+    #   Note that count() is overridden from QAbstractItemModel. The signature
+    #   of the method in that class is "int count()" which makes this slot
+    #   declaration incorrect.
+    #   TODO: fix the pointer when actually using this parameter.
+    @pyqtProperty(int, notify = itemsChanged)
+    def count(self):
         if not self._container:
             return 0
 
         return len(self._row_index_list)
 
+    ##  This function is necessary because it is abstract in QAbstractListModel.
+    #
+    #   Under the hood, Qt will call this function when it needs to know how
+    #   many items are in the model.
+    #   This pyqtSlot will not be linked to the itemsChanged signal, so please
+    #   use the normal count() function instead.
+    @pyqtSlot(QObject, result = int)
+    def rowCount(self, parent = None) -> int:
+        return self.count
+
     ##  Reimplemented from QAbstractListModel
     def data(self, index, role):
         if not self._container:
@@ -524,19 +540,24 @@ class SettingDefinitionsModel(QAbstractListModel):
             if catalog.hasTranslationLoaded():
                 self._i18n_catalog = catalog
 
-        self.beginResetModel()
-
-        self._definition_list.clear()
-        self._row_index_list.clear()
-
         if self._root:
-            self._definition_list = self._root.findDefinitions()
+            new_definitions = self._root.findDefinitions()
         else:
-            self._definition_list = self._container.findDefinitions()
+            new_definitions = self._container.findDefinitions()
 
-        self._scheduleUpdateVisibleRows()
-
-        self.endResetModel()
+        # Check if a full reset is required
+        if len(new_definitions) != len(self._definition_list):
+            self.beginResetModel()
+            self._definition_list = new_definitions
+            self._row_index_list.clear()
+            self._scheduleUpdateVisibleRows()
+            self.endResetModel()
+        else:
+            # If the length hasn't changed, we can just notify that the data was changed. This will prevent the existing
+            # QML setting items from being re-created every you switch between machines.
+            self._definition_list = new_definitions
+            self._scheduleUpdateVisibleRows()
+            self.dataChanged.emit(self.index(0, 0), self.index(len(self._definition_list) - 1, 0))
 
     # Update the list of visible rows.
     #
