@@ -1,4 +1,4 @@
-# Copyright (c) 2015 Ultimaker B.V.
+# Copyright (c) 2018 Ultimaker B.V.
 # Uranium is released under the terms of the LGPLv3 or higher.
 
 from UM.Tool import Tool
@@ -24,6 +24,9 @@ from . import RotateToolHandle
 import math
 import time
 
+from UM.i18n import i18nCatalog
+i18n_catalog = i18nCatalog("uranium")
+
 ##  Provides the tool to rotate meshes and groups
 #
 #   The tool exposes a ToolHint to show the rotation angle of the current operation
@@ -56,13 +59,11 @@ class RotateTool(Tool):
 
         if event.type == Event.KeyPressEvent and event.key == KeyEvent.ShiftKey:
             # Snap is toggled when pressing the shift button
-            self._snap_rotation = (not self._snap_rotation)
-            self.propertyChanged.emit()
+            self.setRotationSnap(not self._snap_rotation)
 
         if event.type == Event.KeyReleaseEvent and event.key == KeyEvent.ShiftKey:
             # Snap is "toggled back" when releasing the shift button
-            self._snap_rotation = (not self._snap_rotation)
-            self.propertyChanged.emit()
+            self.setRotationSnap(not self._snap_rotation)
 
         if event.type == Event.MousePressEvent and self._controller.getToolsEnabled():
             # Start a rotate operation
@@ -98,7 +99,7 @@ class RotateTool(Tool):
             self.setDragStart(event.x, event.y)
             self._rotating = False
             self._angle = 0
-
+            return True
 
         if event.type == Event.MouseMoveEvent:
             # Perform a rotate operation
@@ -119,7 +120,7 @@ class RotateTool(Tool):
             drag_start = (self.getDragStart() - handle_position).normalized()
             drag_position = self.getDragPosition(event.x, event.y)
             if not drag_position:
-                return
+                return False
             drag_end = (drag_position - handle_position).normalized()
 
             try:
@@ -130,7 +131,7 @@ class RotateTool(Tool):
             if self._snap_rotation:
                 angle = int(angle / self._snap_angle) * self._snap_angle
                 if angle == 0:
-                    return
+                    return False
 
             rotation = None
             if self.getLockedAxis() == ToolHandle.XAxis:
@@ -161,6 +162,7 @@ class RotateTool(Tool):
                 op.push()
 
                 self.setDragStart(event.x, event.y)
+            return True
 
         if event.type == Event.MouseReleaseEvent:
             # Finish a rotate operation
@@ -211,7 +213,7 @@ class RotateTool(Tool):
     def resetRotation(self):
 
         for node in self._getSelectedObjectsWithoutSelectedAncestors():
-            node.setMirror(Vector(1,1,1))
+            node.setMirror(Vector(1, 1, 1))
 
         Selection.applyOperation(SetTransformOperation, None, Quaternion(), None)
 
@@ -220,7 +222,7 @@ class RotateTool(Tool):
     #   Note: The LayFlat functionality is mostly used for 3d printing and should probably be moved into the Cura project
     def layFlat(self):
         self.operationStarted.emit(self)
-        self._progress_message = Message("Laying object flat on buildplate...", lifetime = 0, dismissable = False, title = "Object Rotation")
+        self._progress_message = Message(i18n_catalog.i18nc("@label", "Laying object flat on buildplate..."), lifetime = 0, dismissable = False, title = i18n_catalog.i18nc("@title", "Object Rotation"))
         self._progress_message.setProgress(0)
 
         self._iterations = 0
@@ -250,9 +252,10 @@ class RotateTool(Tool):
     #
     #   Note that the LayFlatOperation rate-limits these callbacks to prevent the UI from being flooded with property change notifications,
     #   \param iterations type(int) number of iterations performed since the last callback
-    def _layFlatProgress(self, iterations):
+    def _layFlatProgress(self, iterations: int):
         self._iterations += iterations
-        self._progress_message.setProgress(100 * self._iterations / self._total_iterations)
+        if self._progress_message:
+            self._progress_message.setProgress(100 * self._iterations / self._total_iterations)
 
     ##  Called when the LayFlatJob is done running all of its LayFlatOperations
     #
@@ -264,6 +267,7 @@ class RotateTool(Tool):
 
         self.operationStopped.emit(self)
 
+
 ##  A LayFlatJob bundles multiple LayFlatOperations for multiple selected objects
 #
 #   The job is executed on its own thread, processing each operation in order, so it does not lock up the GUI.
