@@ -56,6 +56,8 @@ class TranslateTool(Tool):
         # Ensure that the properties (X, Y & Z) are updated whenever the selection center is changed.
         Selection.selectionCenterChanged.connect(self.propertyChanged)
 
+        # CURA-5966 Make sure to render whenever objects get selected/deselected.
+        Selection.selectionChanged.connect(self.propertyChanged)
 
     ##  Get the x-location of the selection bounding box center
     #
@@ -249,6 +251,7 @@ class TranslateTool(Tool):
                     self.setLockedAxis(ToolHandle.XAxis)  # Do not move y / vertical
 
             self.setDragPlane(Plane(plane_vector, 0))
+            return True
 
         if event.type == Event.MouseMoveEvent:
             # Perform a translate operation
